clear
set more off
set matsize 1000
capture log close

log using reg-appendix, text replace

import excel using "EDTG_Replication Data.xls", sheet("Sheet1") firstrow

sort gid year
by gid: gen t=_n
gen dstar=0
replace dstar=1 if end==1 /* construct dependent var. */
gen x1=t
gen x2=t^2	

gen lsize=ln(peak_size)
gen terpc=terr_POP
gen tcpa=total_casualties/total_atks
replace tcpa=0 if total_atk==0
gen ly=log(gdppercapita)
gen lpop=ln(pop) 
gen op=tradeopenness2010usd
gen govsp=GovernmentspendingGDP2010us
gen polity1=polity+10
gen polity1sqr=polity1^2
gen ethn2=ethnic^2
gen lelev=log(elevation)


*****************************
*** Appendix Table A1 *******
*****************************
outreg2 using TableA1.xls, replace sum(log) keep(year end duration num_base mul_bases ///
	EAP ECA LAC MENA NA SAS SSA total_atks terr_POP diversity left nat rel ///
	right size peak_size ercsr pch sq tch shr_trans total_deaths total_injuries ///
	total_casualties terr_deaths terr_injuries terr_casualties nonterr_deaths ///
	nonterr_injuries nonterr_casualties endstr terrctrl lead_hierarch drugtk ///
	kidnap state_sponsor num_sponsor social_service public_service num_allies ///
	num_rivals num_enemies fate_leader) ///
	sortvar(year end duration num_base mul_bases ///
	EAP ECA LAC MENA NA SAS SSA total_atks terr_POP diversity left nat rel ///
	right size peak_size ercsr pch sq tch shr_trans total_deaths total_injuries ///
	total_casualties terr_deaths terr_injuries terr_casualties nonterr_deaths ///
	nonterr_injuries nonterr_casualties endstr terrctrl lead_hierarch drugtk ///
	kidnap state_sponsor num_sponsor social_service public_service num_allies ///
	num_rivals num_enemies fate_leader)

	
*****************************
*** Appendix Table A2 *******
*****************************	
gen temp=1
replace temp=2 if year>=1980
replace temp=3 if year>=1990
replace temp=4 if year>=2000
replace temp=5 if year>=2010
xi i.temp
logit dstar _I* i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
tab gid if e(sample), nofreq
display r(r)
outreg2 using TableA2, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lsize 1.left 1.nat 1.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock) dec(3) ///
	title("Logit Regressions of Terrorist Group Failure: Piecewise constant duration")

logit dstar _I* i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
tab gid if e(sample), nofreq
display r(r)
outreg2

logit dstar _I* lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
tab gid if e(sample), nofreq
display r(r)
outreg2

xtset gid year
xtlogit dstar _I* i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)
outreg2
xtlogit dstar _I* i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)
outreg2
xtlogit dstar _I* lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)	
outreg2


*****************************
*** Appendix Table A3 *******
*****************************	
by gid: egen failed=total(dstar) // to analyze groups that ended: 340 groups
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
gen samp=e(sample) // to hold sample constant across models
outreg2 using TableA3, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lsize 1.left 1.nat 1.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock) dec(3) ///
	title("Logit Regressions of Terrorist Group Failure")

foreach var of varlist samp failed {
logit dstar x1 x2 i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob	
tab gid if e(sample), nofreq
display r(r)
outreg2
}


*****************************
*** Appendix Table A4 *******
*****************************
gen tvar1=(year<2002) // 70-01
gen tvar2=(year>2001) // 02-16
logit dstar x*, rob
outreg2 using TableA4, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lsize 1.left 1.nat 1.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock) dec(3) ///
	title("Logit Regressions of Terrorist Group Failure: different time periods")

foreach var of varlist tvar1 tvar2 {
logit dstar x1 x2 i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock if `var'==1, rob	
tab gid if e(sample), nofreq
display r(r)
outreg2
}

log close
