import excel using "EDTG_Replication Data.xls", sheet("Sheet1") firstrow

************ Table 1 ********************************

***Column 3
recode ystart 1970/2001 = 1 2002/2016 = 2, generate(period)
gen ideology=.
replace ideology=1 if left==1
replace ideology=2 if nat==1
replace ideology=3 if rel==1
replace ideology=4 if right==1

tabulate ideology period, column

***Column 2
matrix input x = (139\168\73\24\404)
mat A = x*0.03125  // [1/(2001-1970+1)]=0.03125
matrix list A
matrix input y = (53\135\130\11\329)
mat B = y*0.0666667 // [1/(2016-2002+1)]=0.0666667
matrix list B

***Column 4,5,6  before 2002
gen income=.
replace income=1 if income_level=="L"
replace income=2 if income_level!="H" & income_level!="L"
replace income=3 if income_level=="H"

tabulate ideology income if period==1, column

***Column 4,5,6 2002-2016
tabulate ideology income if period==2, column

***Column 7 before 2002 and 2002-2016
recode y_start 1970/2001 = 1 2002/2016 = 2, generate(prd)
gen regime=.
replace regime=1 if regime_status=="NF"
replace regime=2 if regime_status=="PF"
replace regime=3 if regime_status=="F"

matrix mat1=J(24,1,0)
local p=1
forvalues i=1/3 {
	forvalues j=1/2 {
		forvalues k=1/4 {
			tab gid if regime==`i' & prd==`j' & ideology==`k' , nofreq
			matrix mat1[`p',1]=r(r)
			local p=`p'+1
}
}
}
mat X1=[mat1[1..4,1], mat1[9..12,1], mat1[17..20,1]]
mat a=J(1,4,1)
mat b=a*X1
mat X1=[X1\b]
mat colnames X1 = "Not Free" "Partly Free" "Free"
mat rownames X1 = "Left Wing" "Nationalist" "Religious" "Right Wing" "Total" 
mat X2=[mat1[5..8,1], mat1[13..16,1], mat1[21..24,1]]
mat c=a*X2
mat X2=[X2\c]
mat colnames X2 = "Not Free" "Partly Free" "Free"
mat rownames X2 = "Left Wing" "Nationalist" "Religious" "Right Wing" "Total"
mat list X1
mat list X2

************ Table 2 ************************************

***Column 2
tabulate ideology period

***Column 3
tabulate ideology prd if end==1

***Columns 4 & 5
** before 2002
table ideology if prd==1, c(sum total_atks sum total_casualties)
** after 2002
table ideology if prd==2, c(sum total_atks sum total_casualties)

***Columns 6 & 7: mannually calculate using data from other columns

************ Table 3 ************************************

***Column 2
recode ystart 1970/2001 = 1 2002/2006 = 2 2007/2016 = 3, generate(time1)
recode y_start 1970/2001 = 1 2002/2006 = 2 2007/2016 = 3, generate(time2)
tabulate ideology time1
tabulate ideology if time1!=1 & time1!=.

***Column 3
** before 2002
total num_domestic, over(ideology), if time2==1
** 2002-2016
total num_domestic, over(ideology), if time2!=1 & time2!=.
** 2002-2006
total num_domestic, over(ideology), if time2==2
** 2007-2016
total num_domestic, over(ideology), if time2==3

***Column 4
** before 2002
total num_trans, over(ideology), if time2==1
** 2002-2016
total num_trans, over(ideology), if time2!=1 & time2!=.
** 2002-2006
total num_trans, over(ideology), if time2==2
** 2007-2016
total num_trans, over(ideology), if time2==3

***Column 5: mannually calculate using data in columns 3 & 4

***Column 6
rename public_service svs
tabulate ideology time1 if svs==1
tabulate ideology if svs==1 & time1!=1 & time1!=. 

***Column 7
matrix drop _all
matrix mat1=J(16,1,0)
local p=1
forvalues i=1/3 {
	forvalues j=1/4 {
		tab gid if time2==`i' & ideology==`j' & terrctrl==1, nofreq
		matrix mat1[`p',1]=r(r)
		local p=`p'+1
}
}
local k=13
forvalues j=1/4 {
	tab gid if time2!=1 & ideology==`j' & terrctrl==1, nofreq
	matrix mat1[`k',1]=r(r)
	local k=`k'+1
}
matrix a=J(1,4,1)
matrix b=I(4)
matrix c=b#a
matrix d=c*mat1
matrix Y1=[mat1[1..4,1]\d[1,1]\mat1[13..16,1]\d[4,1]\mat1[5..8,1]\d[2,1]\mat1[9..12,1]\d[3,1]]
mat colnames Y1 = "Holds territory"
mat rownames Y1 = "Left Wing" "Nationalist" "Religious" "Right Wing" "Total" ///
	"Left Wing" "Nationalist" "Religious" "Right Wing" "Total" ///
	"Left Wing" "Nationalist" "Religious" "Right Wing" "Total" ///
	"Left Wing" "Nationalist" "Religious" "Right Wing" "Total"
mat list Y1

***Column 8
** before 2002
total num_kidnap, over(ideology), if time2==1
** 2002-2016
total num_kidnap, over(ideology), if time2!=1 & time2!=.
** 2002-2006
total num_kidnap, over(ideology), if time2==2
** 2007-2016
total num_kidnap, over(ideology), if time2==3
