clear
set more off
set matsize 1000
capture log close

log using reg-results, text replace

import excel using "EDTG_Replication Data.xls", sheet("Sheet1") firstrow

sort gid year
by gid: gen t=_n
gen dstar=0
replace dstar=1 if end==1 /* construct dependent var. */
gen x1=t
gen x2=t^2	

gen lsize=ln(peak_size)
gen terpc=terr_POP
gen tcpa=total_casualties/total_atks
replace tcpa=0 if total_atk==0
gen ly=log(gdppercapita)
gen lpop=ln(pop) 
gen op=tradeopenness2010usd
gen govsp=GovernmentspendingGDP2010us
gen polity1=polity+10
gen polity1sqr=polity1^2
gen ethn2=ethnic^2
gen lelev=log(elevation)


*******************
*** Table 4 *******
*******************
logit dstar x1 x2 i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
tab gid if e(sample), nofreq
display r(r)
outreg2 using Table4, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lsize 1.left 1.nat 1.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock) dec(3) ///
	title("Logit Regressions of Terrorist Group Failure")

logit dstar x1 x2 i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob
tab gid if e(sample), nofreq
display r(r)
outreg2

logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, rob	
tab gid if e(sample), nofreq
display r(r)
outreg2

xtset gid year
xtlogit dstar x1 x2 i.left i.nat i.right shr_trans diversity num_base ///
	lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)
outreg2
xtlogit dstar x1 x2 i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)
outreg2
xtlogit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop op govsp polity1 polity1sqr ethnic ethn2 EAP ECA LAC NA SAS SSA ///
	lelev tropics landlock, vce(rob)	
outreg2


*******************
*** Table 5 *******
*******************
recode fate_leader(2=1)
logit dstar x1 x2
outreg2 using Table5, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lsize 1.left 1.nat 1.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 fate_leader kidnap num_sponsor ///
	num_allies num_enemies) dec(3) ///
	title("Logit Regressions of Terrorist Group Failure")
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 fate_leader, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 kidnap, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 num_sponsor, rob
tab gid if e(sample), nofreq
display r(r)	
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 num_allies num_enemies, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 fate_leader kidnap num_sponsor, rob
tab gid if e(sample), nofreq
display r(r)
outreg2
logit dstar x1 x2 lsize i.left i.nat i.right shr_trans tcpa diversity num_base ///
	ly lpop polity1 ethnic ethn2 fate_leader kidnap num_allies ///
	num_enemies, rob
tab gid if e(sample), nofreq
display r(r)
outreg2


*******************
*** Table 6 *******
*******************
import excel using "EDTG_Replication Data.xls", sheet("Sheet1") firstrow

gen ly = ln(gdppercapita)
gen lpop = ln(pop)
bysort gid: egen maxsize=max(peak_size)
drop lnpeaksize
gen lnpeaksize=ln(maxsize)

keep gid y_start y_end lnpeaksize left nat right rel total_atks nonterr_deaths ///
	ly lpop polity EAP ECA LAC MENA NA SAS SSA competitor
	
collapse (max) y_start y_end lnpeaksize left nat right rel ///
	EAP ECA LAC MENA NA SAS SSA ///
	(sum) total_atks nonterr_deaths ///
	(mean) competitor ///
	(firstnm) ly lpop polity, by(gid)

gen duration=y_end-y_start+1
replace duration=2016-y_start if duration==.
gen dur2=duration^2
gen lcomp=ln(competitor+1)
gen latks=ln(total_atks+1)
gen polity2=polity+10
gen polity2sqr=polity2^2
replace nonterr_deaths=round(nonterr_deaths,1)

nbreg nonterr_deaths lnpeaksize left nat rel duration dur2 lcomp ///
	latks ly lpop polity2, cluster(gid)
outreg2 using Table6, replace excel alpha(0.01, 0.05, 0.10) ///
	sortvar(lnpeaksize left nat rel lcomp latks ly lpop polity2 ///
	polity2sqr EAP ECA LAC NA SAS SSA duration dur2) dec(3) ///
	title("NB Regressions of Group Attacks and Lethality")
	
nbreg nonterr_deaths lnpeaksize left nat rel duration dur2 lcomp ///
	latks ly lpop polity2 polity2sqr EAP ECA LAC NA SAS SSA, cluster(gid)	
outreg2
nbreg total_atks lnpeaksize left nat rel duration dur2 lcomp ///
	ly lpop polity2, cluster(gid)
outreg2
nbreg total_atks lnpeaksize left nat rel duration dur2 lcomp ///
	ly lpop polity2 polity2sqr EAP ECA LAC NA SAS SSA, cluster(gid)
outreg2

log close
